@@ -5,13 +5,15 @@ import yaml
 
 from .dot_proxygen import settings_file
 
+
 def _yaml_settings_file_source(_):
     with settings_file().open() as yaml_file:
         settings = yaml.safe_load(yaml_file)
         return settings or {}
 
+
 class Settings(BaseSettings):
-    endpoint_url: AnyUrl = "https://proxygen.ptl.api.platform.nhs.uk"
+    endpoint_url: AnyUrl = "https://proxygen.prod.api.platform.nhs.uk"
     spec_output_format: Literal["json", "yaml"] = "yaml"
     api: str = None
 
